==> cx88-1.0.2.tar.gz: cx88-1.0.2/utils/cx88_audio_enable.cpp <==
#include <stdlib.h>
#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include "cx88_video_ioctl.h"
#include "tuner_devnode_device.h"

int main(int argc, char **argv)
{
   uint32_t id;
   if (argc < 2)
   {
      printf("Usage: %s <devnode>\n", argv[0]);
      return 1;  
   }
   int fd = open(argv[1], O_RDWR);
   int error = ioctl(fd, CX88_VIDEO_CARD_ID, &id);
   if (error)
   {
      printf("Error during card ID ioctl\n");
      return 1;
   }
   printf("Card ID = 0x%x\n", id);
   cx88_video_i2c_config config;
   config.in_i2c_addrs[0] = 0x50;
   config.in_num_i2c_devices = 1;
   error = ioctl(fd, CX88_VIDEO_I2C_CONFIG, &config);
   if (error)
   {
      printf("Error during I2C config ioctl\n");
      return 1;  
   }
   char eeprom_devnode[CX88_VIDEO_MAX_DEVNODE_NAME + 5];
   sprintf(eeprom_devnode, "/dev/%s", config.out_i2c_devnodes[0]);  
   tuner_config conf;
   tuner_devnode_device eeprom_dev(conf, eeprom_devnode, error);
   if (error)
   {
      printf("Error creating eeprom devnode\n");
      return 1;
   }
   uint8_t buffer[] = {0x00, 0x00};
   error = eeprom_dev.transact(buffer, 1, &(buffer[1]), 1);
   if (error)
   {
      printf("Error reading function enables\n");  
   }
   if (!(buffer[1] & 0x2))
   {
      printf("Audio function not detected: enabling\n");
      buffer[1] |= 0x2;
      size_t written = 0;
      error = eeprom_dev.write(buffer, sizeof(buffer), written);
      if (error || (written == 0))
      {
         printf("Error writing eeprom!\n");
         return 1;
      }
      sleep(10);
   }
   else
   {
      printf("Audio function already enabled: Function mask = 0x%x\n", buffer[1]);  
   }
   close(fd);
   return 0;
}

==> cx88-1.1.0.tar.gz: cx88-1.1.0/utils/cx88_audio_enable.cpp <==
#include <stdlib.h>
#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include "cx88_video_ioctl.h"
#include "tuner_devnode_device.h"

int main(int argc, char **argv)
{
   uint32_t id;
   if (argc < 2)
   {
      printf("Usage: %s <devnode>\n", argv[0]);
      return 1;  
   }
   int fd = open(argv[1], O_RDWR);
   int error = ioctl(fd, CX88_COMMON_CARD_ID, &id);
   if (error)
   {
      printf("Error during card ID ioctl\n");
      return 1;
   }
   printf("Card ID = 0x%x\n", id);
   cx88_common_i2c_config config;
   config.in_i2c_addrs[0] = 0x50;
   config.in_num_i2c_devices = 1;
   error = ioctl(fd, CX88_COMMON_I2C_CONFIG, &config);
   if (error)
   {
      printf("Error during I2C config ioctl\n");
      return 1;  
   }
   char eeprom_devnode[CX88_COMMON_MAX_DEVNODE_NAME + 5];
   sprintf(eeprom_devnode, "/dev/%s", config.out_i2c_devnodes[0]);  
   tuner_config conf;
   tuner_devnode_device eeprom_dev(conf, eeprom_devnode, error);
   if (error)
   {
      printf("Error creating eeprom devnode\n");
      return 1;
   }
   uint8_t buffer[] = {0x00, 0x00};
   error = eeprom_dev.transact(buffer, 1, &(buffer[1]), 1);
   if (error)
   {
      printf("Error reading function enables\n");  
   }
   if (!(buffer[1] & 0x2))
   {
      printf("Audio function not detected: enabling\n");
      buffer[1] |= 0x2;
      size_t written = 0;
      error = eeprom_dev.write(buffer, sizeof(buffer), written);
      if (error || (written == 0))
      {
         printf("Error writing eeprom!\n");
         return 1;
      }
      sleep(10);
   }
   else
   {
      printf("Audio function already enabled: Function mask = 0x%x\n", buffer[1]);  
   }
   close(fd);
   return 0;
}
